@@ -58,13 +58,13 @@ sub  medium_time_format      { $_[0]->time_formats->{medium} }
 sub   short_time_format      { $_[0]->time_formats->{short} }
 sub default_time_format      { $_[0]->time_formats->{ $_[0]->{default_time_format_length} } }
 
-sub datetime_format_pattern_order { $_[0]->date_before_time ? (0, 1) : (1, 0) }
+sub _datetime_format_pattern_order { $_[0]->date_before_time ? (0, 1) : (1, 0) }
 
-sub    full_datetime_format { join ' ', ( $_[0]->full_date_format, $_[0]->full_time_format )[ $_[0]->datetime_format_pattern_order ] }
-sub    long_datetime_format { join ' ', ( $_[0]->long_date_format, $_[0]->long_time_format )[ $_[0]->datetime_format_pattern_order ] }
-sub  medium_datetime_format { join ' ', ( $_[0]->medium_date_format, $_[0]->medium_time_format )[ $_[0]->datetime_format_pattern_order ] }
-sub   short_datetime_format { join ' ', ( $_[0]->short_date_format, $_[0]->short_time_format )[ $_[0]->datetime_format_pattern_order ] }
-sub default_datetime_format { join ' ', ( $_[0]->default_date_format, $_[0]->default_time_format )[ $_[0]->datetime_format_pattern_order ] }
+sub    full_datetime_format { join ' ', ( $_[0]->full_date_format, $_[0]->full_time_format )[ $_[0]->_datetime_format_pattern_order ] }
+sub    long_datetime_format { join ' ', ( $_[0]->long_date_format, $_[0]->long_time_format )[ $_[0]->_datetime_format_pattern_order ] }
+sub  medium_datetime_format { join ' ', ( $_[0]->medium_date_format, $_[0]->medium_time_format )[ $_[0]->_datetime_format_pattern_order ] }
+sub   short_datetime_format { join ' ', ( $_[0]->short_date_format, $_[0]->short_time_format )[ $_[0]->_datetime_format_pattern_order ] }
+sub default_datetime_format { join ' ', ( $_[0]->default_date_format, $_[0]->default_time_format )[ $_[0]->_datetime_format_pattern_order ] }
 
 sub default_date_format_length { $_[0]->{default_date_format_length} }
 sub default_time_format_length { $_[0]->{default_time_format_length} }
@@ -97,11 +97,6 @@ DateTime::Locale::Base - Base class for individual locale objects
 
   use base 'DateTime::Locale::Base';
 
-=head1 SUPPORT
-
-Support for this module is provided via the datetime@perl.org email
-list. See http://lists.perl.org/ for more details.
-
 =head1 DEFAULT FORMATS
 
 Each locale has a set of four default date and time formats.  They are
@@ -184,6 +179,11 @@ locale.
 
 =back
 
+=head1 SUPPORT
+
+Support for this module is provided via the datetime@perl.org email
+list. See http://lists.perl.org/ for more details.
+
 =head1 AUTHORS
 
 Richard Evans <rich@ridas.com>
